@@ -14,7 +14,7 @@ class TestModel(unittest.TestCase):
         self.gpf = GPF('prison', self.data)
 
     def test_calculate_metrics_dict(self):
-        model, like = self.gpf.train(n_iterations=100)
+        model, like = self.gpf.train(epochs=100)
         samples = self.gpf.predict(model, like)
         res = self.gpf.metrics(samples)
         self.assertLess(res['mase']['bottom'], 2.5)
