@@ -11,13 +11,13 @@ class TestModel(unittest.TestCase):
         self.n = self.data['predict']['n']
         self.s = self.data['train']['s']
         shutil.rmtree("./data/original_datasets")
-        self.gpf = GPF('police', self.data)
+        self.gpf = GPF('police', self.data, log_dir="..")
 
     def test_correct_train(self):
-        model, like = self.gpf.train(n_iterations=10)
+        model, like = self.gpf.train(epochs=10)
         self.assertIsNotNone(model)
 
     def test_predict_shape(self):
-        model, like = self.gpf.train(n_iterations=10)
+        model, like = self.gpf.train(epochs=10)
         samples = self.gpf.predict(model, like)
         self.assertTrue(samples.shape == (self.n, self.s, 500))
